<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nl">
<context>
    <name>AptConfigMessage</name>
    <message>
        <location filename="../src/deb-installer/view/pages/AptConfigMessage.cpp" line="85"/>
        <source>Enter the number to configure: </source>
        <translation>Voer het nummer in om in te stellen: </translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/AptConfigMessage.cpp" line="90"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>Oké</translation>
    </message>
</context>
<context>
    <name>BackendProcessPage</name>
    <message>
        <location filename="../src/deb-installer/view/pages/backendprocesspage.cpp" line="18"/>
        <source>Loading packages...</source>
        <translation>Bezig met laden van pakketten…</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/backendprocesspage.cpp" line="19"/>
        <source>%1/%2 loaded</source>
        <translation>%1/%2 geladen</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/backendprocesspage.cpp" line="22"/>
        <source>Initializing...</source>
        <translation>Bezig met inlezen…</translation>
    </message>
</context>
<context>
    <name>DdimErrorPage</name>
    <message>
        <location filename="../src/deb-installer/view/pages/ddimerrorpage.cpp" line="18"/>
        <source>OK</source>
        <translation>Oké</translation>
    </message>
</context>
<context>
    <name>DebInstaller</name>
    <message>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="118"/>
        <source>Package Installer</source>
        <translation>Pakketinstallatie</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="128"/>
        <source>Settings</source>
        <translation>Instellingen</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="695"/>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="819"/>
        <source>Installing other packages... Please open it later.</source>
        <translation>Bezig met installeren van andere pakketten… Keer later terug.</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="700"/>
        <source>Parsing failed: An illegal file structure was found in the manifest file!</source>
        <translation>Verwerking mislukt: onjuiste bestandsstructuur aangetroffen in manifestbestand!</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="702"/>
        <source>Parsing failed: An illegal version number was found in the manifest file!</source>
        <translation>Verwerking mislukt: ongeldig versienummer aangetroffen in manifestbestand!</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="704"/>
        <source>No deb packages found. Please check the folder.</source>
        <translation>Er zijn geen deb-pakketten aangetroffen - controleer de map.</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="842"/>
        <source>The %1 package may be broken</source>
        <translation>Het %1-pakket is mogelijk beschadigd</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="851"/>
        <source>You can only install local %1 packages</source>
        <translation>Je kunt alleen lokale %1-pakketten installeren</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="860"/>
        <source>No permission to access this folder</source>
        <translation>Geen toegang tot deze map</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="877"/>
        <source>Already Added</source>
        <translation>Reeds toegevoegd</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="886"/>
        <source>%1 does not exist, please reselect</source>
        <translation>%1 bestaat niet - kies een ander bestand</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="445"/>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="894"/>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="1047"/>
        <source>Bulk Install</source>
        <translation>Alles installeren</translation>
    </message>
</context>
<context>
    <name>DebListModel</name>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="104"/>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="127"/>
        <source>Installation failed, please check your network connection</source>
        <translation>Installatie mislukt: controleer je internetverbinding.</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="108"/>
        <source>Installation failed, please check for updates in Control Center</source>
        <translation>Installatie mislukt: controleer op updates in het instellingencentrum.</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="111"/>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="117"/>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="133"/>
        <source>Installation failed, insufficient disk space</source>
        <translation>Installatie mislukt: onvoldoende schijfruimte.</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="139"/>
        <source>No digital signature</source>
        <translation>Geen digitale handtekening</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="144"/>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="895"/>
        <source>Invalid digital signature</source>
        <translation>Ongeldige digitale handtekening</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="152"/>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="880"/>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1981"/>
        <source>The administrator has set policies to prevent installation of this package</source>
        <translation>De beheerder voert een beleid wat voorkomt dat dit pakket geïnstalleerd mag worden</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="159"/>
        <source>Installation Failed</source>
        <translation>Installatie mislukt</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="863"/>
        <source>current system</source>
        <translation>Huidig systeem</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="866"/>
        <source>%2 has been installed in %1, please uninstall this package before installing it</source>
        <translation>%2 is geïnstalleerd in %1. Verwijder dit pakket alvorens het nieuwe pakket te installeren.</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="873"/>
        <source>Broken dependencies, try installing the app in compatibility mode</source>
        <translation>Er is een probleem met de afhankelijkheden. Probeer het pakket in compatibiliteitsmodus te installeren.</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="876"/>
        <source>Compatibility mode installation failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="898"/>
        <source>Failed to install %1</source>
        <translation>%1 kan niet worden geïnstalleerd</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1328"/>
        <source>Unable to install - no digital signature</source>
        <translation>Kan niet installeren: geen digitale handtekening</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1329"/>
        <source>Please go to Control Center to enable developer mode and try again. Proceed?</source>
        <translation>Ga naar de systeeminstellingen, schakel de ontwikkelaarsmodus in en probeer het opnieuw. Wil je doorgaan?</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1332"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Annuleren</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1333"/>
        <source>Proceed</source>
        <comment>button</comment>
        <translation>Doorgaan</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1280"/>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1394"/>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1983"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>Oké</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1284"/>
        <source>Failed to install %1: no valid digital signature</source>
        <translation>Kan %1 niet installeren: geen digitale handtekening</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1435"/>
        <source>This package does not have a valid digital signature. Continue with the installation?</source>
        <translation>Dit pakket bevat geen geldige ondertekening. Weet je zeker dat je wilt doorgaan?</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1437"/>
        <source>Cancel</source>
        <translation>Annuleren</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1438"/>
        <source>Continue</source>
        <comment>button</comment>
        <translation>Doorgaan</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1278"/>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1391"/>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1980"/>
        <source>Unable to install</source>
        <translation>Installeren niet mogelijk</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1392"/>
        <source>This package does not have a valid digital signature</source>
        <translation>Dit pakket bevat geen geldige ondertekening</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="902"/>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="908"/>
        <source>Broken dependencies: %1</source>
        <translation>Niet-voldane afhankelijkheden: %1</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="149"/>
        <source>Authentication failed</source>
        <translation>Authenticatie mislukt</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="834"/>
        <source>Unmatched package architecture</source>
        <translation>Pakketarchitectuur komt niet overeen</translation>
    </message>
</context>
<context>
    <name>FileChooseWidget</name>
    <message>
        <location filename="../src/deb-installer/view/widgets/filechoosewidget.cpp" line="51"/>
        <source>Drag deb packages here</source>
        <translation>Sleep een deb-bestand hierheen</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/widgets/filechoosewidget.cpp" line="93"/>
        <source>Select File</source>
        <translation>Kies een bestand</translation>
    </message>
</context>
<context>
    <name>MultipleInstallPage</name>
    <message>
        <location filename="../src/deb-installer/view/pages/multipleinstallpage.cpp" line="35"/>
        <source>Show details</source>
        <translation>Informatie tonen</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/multipleinstallpage.cpp" line="35"/>
        <source>Collapse</source>
        <comment>button</comment>
        <translation>Inklappen</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/multipleinstallpage.cpp" line="179"/>
        <source>Install</source>
        <comment>button</comment>
        <translation>Installeren</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/multipleinstallpage.cpp" line="180"/>
        <source>Done</source>
        <comment>button</comment>
        <translation>Klaar</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/multipleinstallpage.cpp" line="182"/>
        <source>Back</source>
        <comment>button</comment>
        <translation>Terug</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/multipleinstallpage.cpp" line="545"/>
        <source>Install %1 will remove: </source>
        <translation>Door %1 wordt het volgende verwijderd:</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/multipleinstallpage.cpp" line="563"/>
        <source>Dependencies in the repository</source>
        <translation>Afhankelijkheden in de pakketbron</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/multipleinstallpage.cpp" line="570"/>
        <source>Missing dependencies</source>
        <translation>Ontbrekende afhankelijkheden</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/multipleinstallpage.cpp" line="629"/>
        <source>Installing dependencies: %1</source>
        <translation>Bezig met installeren van afhankelijkheden: %1</translation>
    </message>
</context>
<context>
    <name>PackageSelectItem</name>
    <message>
        <location filename="../src/deb-installer/view/widgets/packageselectitem.cpp" line="87"/>
        <source>Same version installed</source>
        <translation>Dezelfde versie is geïnstalleerd</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/widgets/packageselectitem.cpp" line="91"/>
        <source>Earlier version installed: %1</source>
        <translation>Oudere versie geïnstalleerd: %1</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/widgets/packageselectitem.cpp" line="96"/>
        <source>Later version installed: %1</source>
        <translation>Nieuwere versie geïnstalleerd: %1</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/widgets/packageselectitem.cpp" line="102"/>
        <source>Unmatched package architecture</source>
        <translation>Pakketarchitectuur komt niet overeen</translation>
    </message>
</context>
<context>
    <name>PackageSelectView</name>
    <message>
        <location filename="../src/deb-installer/view/pages/packageselectview.cpp" line="23"/>
        <source>Select all</source>
        <translation>Alles selecteren</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/packageselectview.cpp" line="24"/>
        <source>Install</source>
        <comment>button</comment>
        <translation>Installeren</translation>
    </message>
</context>
<context>
    <name>PackagesListDelegate</name>
    <message>
        <location filename="../src/deb-installer/model/packageslistdelegate.cpp" line="62"/>
        <source>Installing</source>
        <translation>Bezig met installeren</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/packageslistdelegate.cpp" line="66"/>
        <source>Installed</source>
        <translation>Geïnstalleerd</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/packageslistdelegate.cpp" line="74"/>
        <source>Failed</source>
        <translation>Mislukt</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/packageslistdelegate.cpp" line="70"/>
        <source>Waiting</source>
        <translation>Bezig met wachten</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/packageslistdelegate.cpp" line="246"/>
        <source>Same version installed</source>
        <translation>Dezelfde versie is geïnstalleerd</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/packageslistdelegate.cpp" line="248"/>
        <source>Later version installed: %1</source>
        <translation>Nieuwere versie geïnstalleerd: %1</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/packageslistdelegate.cpp" line="250"/>
        <source>Earlier version installed: %1</source>
        <translation>Oudere versie geïnstalleerd: %1</translation>
    </message>
</context>
<context>
    <name>PackagesListView</name>
    <message>
        <location filename="../src/deb-installer/model/packagelistview.cpp" line="189"/>
        <source>Delete</source>
        <translation>Verwijderen</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <location filename="../src/deb-installer/view/pages/multipleinstallpage.cpp" line="32"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="50"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="52"/>
        <source>Collapse</source>
        <comment>button</comment>
        <translation>Inklappen</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/deb-installer/view/pages/setting_translation.cpp" line="9"/>
        <source>Basic</source>
        <translation>Algemeen</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/setting_translation.cpp" line="10"/>
        <source>Check digital signatures if the developer mode is enabled</source>
        <translation>Ondertekeningen controleren in ontwikkelaarsmodus</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/settingdialog.cpp" line="88"/>
        <source>To install unsigned apps, go to Security Center &gt; Tools &gt; App Security, and select the app types that can be installed.</source>
        <translation>Ga naar Beveiligingscentrum → Hulpmiddelen → Programmabeveiliging en kies de programmasoorten die geïnstalleerd mogen worden.</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/settingdialog.cpp" line="90"/>
        <source>Security Center &gt; Tools &gt; App Security</source>
        <translation>Beveiligingscentrum → Hulpmiddelen → Programmabeveiliging</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/uab/uab_package.cpp" line="54"/>
        <source>The system has not installed Linglong environment, please install it first</source>
        <translation>De Linglong-omgeving is nog niet geïnstalleerd - doe dit handmatig</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/widgets/error_notify_dialog_helper.cpp" line="47"/>
        <source>Unable to install</source>
        <translation>Installeren niet mogelijk</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/widgets/error_notify_dialog_helper.cpp" line="49"/>
        <source>This package does not have a valid digital signature and has been blocked from installing/running. Go to Security Center &gt; Tools &gt; App Security to change the settings.</source>
        <translation>Dit pakket bevat geen geldige ondertekening en is daarom geblokkeerd. Ga naar Beveiligingscentrum → Hulpmiddelen → Programmabeveiliging om de instellingen te wijzigen.</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/widgets/error_notify_dialog_helper.cpp" line="52"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation type="unfinished">Annuleren</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/widgets/error_notify_dialog_helper.cpp" line="53"/>
        <source>Proceed</source>
        <comment>button</comment>
        <translation>Doorgaan</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/packageslistdelegate.cpp" line="282"/>
        <source>Will remove: </source>
        <translation>Wordt verwijderd:</translation>
    </message>
</context>
<context>
    <name>SingleInstallPage</name>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="1035"/>
        <source>Collapse</source>
        <translation>Inklappen</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="519"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="1233"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="1438"/>
        <source>Reinstall</source>
        <translation>Opnieuw installeren</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="1238"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="1443"/>
        <source>Later version installed: %1</source>
        <translation>Nieuwere versie geïnstalleerd: %1</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="1239"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="1444"/>
        <source>Downgrade</source>
        <translation>Afwaarderen</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="1244"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="1449"/>
        <source>Earlier version installed: %1</source>
        <translation>Oudere versie geïnstalleerd: %1</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="1336"/>
        <source>Installing dependencies: %1</source>
        <translation>Bezig met installeren van afhankelijkheden: %1</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="1499"/>
        <source>Failed to install %1</source>
        <translation>%1 kan niet worden geïnstalleerd</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="244"/>
        <source>Version: </source>
        <translation>Versie:</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="190"/>
        <source>Select a compatibility mode:</source>
        <translation>Kies een compatibiliteitsmodus:</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="511"/>
        <source>Install</source>
        <comment>button</comment>
        <translation>Installeren</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="515"/>
        <source>Remove</source>
        <comment>button</comment>
        <translation>Verwijderen</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="523"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>Oké</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="527"/>
        <source>Back</source>
        <comment>button</comment>
        <translation>Terug</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="531"/>
        <source>Done</source>
        <comment>button</comment>
        <translation>Klaar</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="777"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="818"/>
        <source>Trying to install %2 in %1 compatibility mode</source>
        <translation>Probeer %2 in de %1-compatibiliteitsmodus te installeren</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="858"/>
        <source>Uninstalling %2 from %1 compatibility mode</source>
        <translation>Bezig met verwijderen van %2 uit de %1-compatibiliteitsmodus…</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="987"/>
        <source>%2 was successfully installed to %1 compatibility mode</source>
        <translation>%2 is succesvol geïnstalleerd in %1 compatibiliteitsmodus</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="991"/>
        <source>Installed successfully</source>
        <translation>Installatie voltooid</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="1000"/>
        <source>%2 has been successfully uninstalled from %1 compatibility mode</source>
        <translation>%2 is verwijderd uit de %1-compatibiliteitsmodus</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="1004"/>
        <source>Uninstalled successfully</source>
        <translation>Verwijderd</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="1024"/>
        <source>Uninstall Failed</source>
        <translation>Opnieuw installeren mislukt</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="1070"/>
        <source>Install %1 will remove: </source>
        <translation>Door %1 wordt het volgende verwijderd:</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="1091"/>
        <source>Dependencies in the repository</source>
        <translation>Afhankelijkheden in de pakketbron</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="1098"/>
        <source>Missing dependencies</source>
        <translation>Ontbrekende afhankelijkheden</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="1245"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="1450"/>
        <source>Update</source>
        <comment>button</comment>
        <translation>Bijwerken</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="1505"/>
        <source>Invalid digital signature</source>
        <translation>Ongeldige digitale handtekening</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="232"/>
        <source>Name: </source>
        <translation>Naam:</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="1232"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="1437"/>
        <source>Same version installed</source>
        <translation>Dezelfde versie is geïnstalleerd</translation>
    </message>
</context>
<context>
    <name>SingleInstallPage_Install</name>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="50"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="762"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="803"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="984"/>
        <source>Show details</source>
        <translation>Informatie tonen</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/multipleinstallpage.cpp" line="32"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="51"/>
        <source>Show dependencies</source>
        <translation>Afhankelijkheden tonen</translation>
    </message>
</context>
<context>
    <name>SingleInstallPage_Uninstall</name>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="843"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="997"/>
        <source>Show details</source>
        <translation>Informatie tonen</translation>
    </message>
</context>
<context>
    <name>Uab::UabPackageListModel</name>
    <message>
        <location filename="../src/deb-installer/uab/uab_package_list_model.cpp" line="557"/>
        <source>Installation Failed</source>
        <translation>Installatie mislukt</translation>
    </message>
</context>
<context>
    <name>UninstallConfirmPage</name>
    <message>
        <location filename="../src/deb-installer/view/pages/uninstallconfirmpage.cpp" line="17"/>
        <source>Show related packages</source>
        <translation>Gerelateerde pakketten tonen</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/uninstallconfirmpage.cpp" line="17"/>
        <source>Collapse</source>
        <comment>button</comment>
        <translation>Inklappen</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/uninstallconfirmpage.cpp" line="39"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Annuleren</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/uninstallconfirmpage.cpp" line="41"/>
        <source>Confirm</source>
        <translation>Verwijderen</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/uninstallconfirmpage.cpp" line="131"/>
        <source>Are you sure you want to uninstall %1?
All dependencies will also be removed</source>
        <translation>Weet je zeker dat je %1 wilt verwijderen?
Alle afhankelijkheden worden eveneens verwijderd.</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/uninstallconfirmpage.cpp" line="133"/>
        <source>Are you sure you want to uninstall %1?
The system or other applications may not work properly</source>
        <translation>Weet je zeker dat je %1 wilt verwijderen?
Het systeem of andere programma&apos;s werken dan mogelijk niet goed meer.</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/uninstallconfirmpage.cpp" line="177"/>
        <source>Are you sure you want to uninstall %2 
from %1 compatibility mode?</source>
        <translation>Weet je zeker dat je %2 uit de %1-compatibiliteitsmodus wilt verwijderen?</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../src/deb-installer/main.cpp" line="48"/>
        <location filename="../src/deb-installer/main.cpp" line="49"/>
        <source>Package Installer</source>
        <translation>Pakketinstallatie</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/main.cpp" line="50"/>
        <source>Package Installer helps users install and remove local packages, and supports bulk installation.</source>
        <translation>Pakketinstallatie is een programma dat gebruikers helpt bij het installeren van lokale software.</translation>
    </message>
</context>
</TS>
